@@ -6,6 +6,7 @@
 
 #include <config.h>
 #include "gal-a11y-e-tree.h"
+#include "gal-a11y-e-tree-factory.h"
 #include "gal-a11y-util.h"
 #include "gal-a11y-e-table-item.h"
 #include <gal/e-table/e-tree.h>
@@ -35,11 +36,6 @@ init_child_item (GalA11yETree *a11y)
 	eti = e_tree_get_item (tree);
 	if (priv->child_item == NULL) {
 		priv->child_item = atk_gobject_accessible_for_object (G_OBJECT (eti));
-		if (!priv->child_item)
-			priv->child_item = gal_a11y_e_table_item_new (ATK_OBJECT (a11y),eti, 0);
-
-		g_return_if_fail (priv->child_item);
-		priv->child_item->role = ATK_ROLE_TREE_TABLE;
 	}
 }
 
@@ -72,6 +68,12 @@ et_ref_child (AtkObject *accessible,
 	return GET_PRIVATE (a11y)->child_item;
 }
 
+static AtkLayer
+et_get_layer (AtkComponent *component)
+{
+	return ATK_LAYER_WIDGET;
+}
+
 static void
 et_class_init (GalA11yETreeClass *klass)
 {
@@ -87,6 +89,7 @@ static void
 et_atk_component_iface_init (AtkComponentIface *iface)
 {
 	iface->ref_accessible_at_point = et_ref_accessible_at_point;
+	iface->get_layer = et_get_layer;
 }
 
 static void
@@ -160,3 +163,14 @@ gal_a11y_e_tree_new (GObject *widget)
 
 	return ATK_OBJECT (a11y);
 }
+
+void
+gal_a11y_e_tree_init (void)
+{
+	if (atk_get_root ())
+		atk_registry_set_factory_type (atk_get_default_registry (),
+					E_TREE_TYPE,
+					gal_a11y_e_tree_factory_get_type ());
+
+}
+
